@@ -1,3 +1,4 @@
+import os
 import signal
 import traceback
 
@@ -39,7 +40,7 @@ class Login(Command):
         if debug:
             Config().set('debug.show-out', True)
 
-        username: str = None
+        username: str = os.getenv('USERNAME')
         if len(args) > 0:
             username = args[0]
 
